<?php


/**
 * Part of the Antares package.
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the 3-clause BSD License.
 *
 * This source file is subject to the 3-clause BSD License that is
 * bundled with this package in the LICENSE file.
 *
 * @package    Automation
 * @version    0.9.0
 * @author     Antares Team
 * @license    BSD License (3-clause)
 * @copyright  (c) 2017, Antares
 * @link       http://antaresproject.io
 */



namespace Antares\Automation\Model;

use Antares\Model\Eloquent;

class JobResults extends Eloquent
{

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'tbl_job_results';

    /**
     * The class name to be used in polymorphic relations.
     *
     * @var string
     */
    protected $morphClass = 'JobResults';

    /**
     * Indicates if the model should be timestamped.
     *
     * @var bool
     */
    public $timestamps = false;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = ['job_id', 'has_error', 'runtime', 'return'];

    /**
     * relation to job table
     * 
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function job()
    {
        return $this->belongsTo(Jobs::class, 'job_id', 'id');
    }

    /**
     * relation to job errors table
     * 
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function jobErrors()
    {
        return $this->belongsTo(JobErrors::class, 'result_job_id', 'id');
    }

}
